/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.8.6
 *
 * Copyright (c) 2023 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 125 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qtreewidget.sip"
#include <qtreewidget.h>
#line 29 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"

#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 33 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qtreewidget.sip"
#include <qtreewidget.h>
#line 39 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 67 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 42 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 27 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 45 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 570 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 48 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 51 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qabstractitemmodel.sip"
#include <qabstractitemmodel.h>
#line 54 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 57 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmimedata.sip"
#include <qmimedata.h>
#line 60 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 63 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 66 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 36 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 69 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 72 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 75 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 78 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 81 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 67 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 84 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 87 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 169 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qitemselectionmodel.sip"
#include <qitemselectionmodel.h>
#line 90 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 592 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 93 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 363 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 96 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 205 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 99 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 102 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qregion.sip"
#include <qregion.h>
#line 105 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 579 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 108 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 111 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 398 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 114 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 117 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 120 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 442 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 123 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qheaderview.sip"
#include <qheaderview.h>
#line 126 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 129 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 509 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 132 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 135 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractitemdelegate.sip"
#include <qabstractitemdelegate.h>
#line 138 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 425 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 141 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 384 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 144 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 619 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 147 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 608 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 150 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractitemview.sip"
#include <qabstractitemview.h>
#line 153 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qabstractscrollarea.sip"
#include <qabstractscrollarea.h>
#line 156 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 159 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 162 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qscrollbar.sip"
#include <qscrollbar.h>
#line 165 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 482 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 168 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 253 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 171 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmargins.sip"
#include <qmargins.h>
#line 174 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 208 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 177 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qframe.sip"
#include <qframe.h>
#line 180 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qscreen.sip"
#include <qscreen.h>
#line 183 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 186 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 30 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 189 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qwindow.sip"
#include <qwindow.h>
#line 192 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 198 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 201 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 204 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgraphicseffect.sip"
#include <qgraphicseffect.h>
#line 207 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qgraphicsproxywidget.sip"
#include <qgraphicsproxywidget.h>
#line 210 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 195 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qglobal.sip"
#include <QtGlobal>
#line 213 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qlocale.sip"
#include <qlocale.h>
#line 216 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 219 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 28 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 222 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontinfo.sip"
#include <qfontinfo.h>
#line 225 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 228 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qfont.sip"
#include <qfont.h>
#line 231 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 471 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 234 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 460 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 237 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 675 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 240 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 302 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 243 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 438 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 246 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 412 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 249 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 52 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 255 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 258 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qlayout.sip"
#include <qlayout.h>
#line 261 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 264 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 267 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qkeysequence.sip"
#include <qkeysequence.h>
#line 270 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qcursor.sip"
#include <qcursor.h>
#line 273 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qbitmap.sip"
#include <qbitmap.h>
#line 276 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 279 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 282 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 287 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 290 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 252 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 293 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 38 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 296 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 149 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 299 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 302 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 305 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 308 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 311 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"
#line 26 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 314 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"


class sipQTreeWidget : public ::QTreeWidget
{
public:
    sipQTreeWidget(::QWidget*);
    virtual ~sipQTreeWidget();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    ::Qt::DropActions supportedDropActions() const SIP_OVERRIDE;
    bool dropMimeData(::QTreeWidgetItem*, int, const ::QMimeData*, ::Qt::DropAction) SIP_OVERRIDE;
    ::QMimeData* mimeData(const QList<::QTreeWidgetItem*>) const SIP_OVERRIDE;
    ::QStringList mimeTypes() const SIP_OVERRIDE;
    ::QStyleOptionViewItem viewOptions() const SIP_OVERRIDE;
    void startDrag(::Qt::DropActions) SIP_OVERRIDE;
    ::QItemSelectionModel::SelectionFlags selectionCommand(const ::QModelIndex&, const ::QEvent*) const SIP_OVERRIDE;
    bool edit(const ::QModelIndex&, ::QAbstractItemView::EditTrigger, ::QEvent*) SIP_OVERRIDE;
    ::QModelIndexList selectedIndexes() const SIP_OVERRIDE;
    ::QRegion visualRegionForSelection(const ::QItemSelection&) const SIP_OVERRIDE;
    void setSelection(const ::QRect&, ::QItemSelectionModel::SelectionFlags) SIP_OVERRIDE;
    bool isIndexHidden(const ::QModelIndex&) const SIP_OVERRIDE;
    int verticalOffset() const SIP_OVERRIDE;
    int horizontalOffset() const SIP_OVERRIDE;
    ::QModelIndex moveCursor(::QAbstractItemView::CursorAction, ::Qt::KeyboardModifiers) SIP_OVERRIDE;
    void editorDestroyed(::QObject*) SIP_OVERRIDE;
    void commitData(::QWidget*) SIP_OVERRIDE;
    void closeEditor(::QWidget*, ::QAbstractItemDelegate::EndEditHint) SIP_OVERRIDE;
    void horizontalScrollbarValueChanged(int) SIP_OVERRIDE;
    void verticalScrollbarValueChanged(int) SIP_OVERRIDE;
    void horizontalScrollbarAction(int) SIP_OVERRIDE;
    void verticalScrollbarAction(int) SIP_OVERRIDE;
    void updateGeometries() SIP_OVERRIDE;
    void updateEditorGeometries() SIP_OVERRIDE;
    void updateEditorData() SIP_OVERRIDE;
    void currentChanged(const ::QModelIndex&, const ::QModelIndex&) SIP_OVERRIDE;
    void selectionChanged(const ::QItemSelection&, const ::QItemSelection&) SIP_OVERRIDE;
    void rowsAboutToBeRemoved(const ::QModelIndex&, int, int) SIP_OVERRIDE;
    void rowsInserted(const ::QModelIndex&, int, int) SIP_OVERRIDE;
    void dataChanged(const ::QModelIndex&, const ::QModelIndex&, const ::QVector<int>&) SIP_OVERRIDE;
    void selectAll() SIP_OVERRIDE;
    void setRootIndex(const ::QModelIndex&) SIP_OVERRIDE;
    void reset() SIP_OVERRIDE;
    int sizeHintForColumn(int) const SIP_OVERRIDE;
    int sizeHintForRow(int) const SIP_OVERRIDE;
    ::QModelIndex indexAt(const ::QPoint&) const SIP_OVERRIDE;
    void scrollTo(const ::QModelIndex&, ::QAbstractItemView::ScrollHint) SIP_OVERRIDE;
    ::QRect visualRect(const ::QModelIndex&) const SIP_OVERRIDE;
    void keyboardSearch(const ::QString&) SIP_OVERRIDE;
    void setSelectionModel(::QItemSelectionModel*) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    int metric(::QPaintDevice::PaintDeviceMetric) const SIP_OVERRIDE;
    ::QPaintEngine* paintEngine() const SIP_OVERRIDE;
    int devType() const SIP_OVERRIDE;
    void setVisible(bool) SIP_OVERRIDE;
    ::QSize sizeHint() const SIP_OVERRIDE;
    ::QSize minimumSizeHint() const SIP_OVERRIDE;
    int heightForWidth(int) const SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*) SIP_OVERRIDE;
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void keyPressEvent(::QKeyEvent*) SIP_OVERRIDE;
    void keyReleaseEvent(::QKeyEvent*) SIP_OVERRIDE;
    void focusInEvent(::QFocusEvent*) SIP_OVERRIDE;
    void focusOutEvent(::QFocusEvent*) SIP_OVERRIDE;
    void enterEvent(::QEvent*) SIP_OVERRIDE;
    void leaveEvent(::QEvent*) SIP_OVERRIDE;
    void paintEvent(::QPaintEvent*) SIP_OVERRIDE;
    void moveEvent(::QMoveEvent*) SIP_OVERRIDE;
    void resizeEvent(::QResizeEvent*) SIP_OVERRIDE;
    void closeEvent(::QCloseEvent*) SIP_OVERRIDE;
    void contextMenuEvent(::QContextMenuEvent*) SIP_OVERRIDE;
    void tabletEvent(::QTabletEvent*) SIP_OVERRIDE;
    void actionEvent(::QActionEvent*) SIP_OVERRIDE;
    void dragEnterEvent(::QDragEnterEvent*) SIP_OVERRIDE;
    void dragMoveEvent(::QDragMoveEvent*) SIP_OVERRIDE;
    void dragLeaveEvent(::QDragLeaveEvent*) SIP_OVERRIDE;
    void dropEvent(::QDropEvent*) SIP_OVERRIDE;
    void showEvent(::QShowEvent*) SIP_OVERRIDE;
    void hideEvent(::QHideEvent*) SIP_OVERRIDE;
    void changeEvent(::QEvent*) SIP_OVERRIDE;
    void inputMethodEvent(::QInputMethodEvent*) SIP_OVERRIDE;
    ::QVariant inputMethodQuery(::Qt::InputMethodQuery) const SIP_OVERRIDE;
    bool focusNextPrevChild(bool) SIP_OVERRIDE;
    bool hasHeightForWidth() const SIP_OVERRIDE;
    bool nativeEvent(const ::QByteArray&, void*, long*) SIP_OVERRIDE;
    ::QPainter* sharedPainter() const SIP_OVERRIDE;
    void initPainter(::QPainter*) const SIP_OVERRIDE;
    ::QSize viewportSizeHint() const SIP_OVERRIDE;
    bool viewportEvent(::QEvent*) SIP_OVERRIDE;
    void scrollContentsBy(int, int) SIP_OVERRIDE;
    void setupViewport(::QWidget*) SIP_OVERRIDE;
    void drawRow(::QPainter*, const ::QStyleOptionViewItem&, const ::QModelIndex&) const SIP_OVERRIDE;
    void drawBranches(::QPainter*, const ::QRect&, const ::QModelIndex&) const SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQTreeWidget(const sipQTreeWidget &);
    sipQTreeWidget &operator = (const sipQTreeWidget &);

    char sipPyMethods[92];
};

sipQTreeWidget::sipQTreeWidget(::QWidget*a0): ::QTreeWidget(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQTreeWidget::~sipQTreeWidget()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQTreeWidget::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf, sipType_QTreeWidget);

    return ::QTreeWidget::metaObject();
}

int sipQTreeWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QTreeWidget::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf, sipType_QTreeWidget, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQTreeWidget::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QTreeWidget, _clname, &sipCpp) ? sipCpp : ::QTreeWidget::qt_metacast(_clname));
}

::Qt::DropActions sipQTreeWidget::supportedDropActions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportedDropActions);

    if (!sipMeth)
        return ::QTreeWidget::supportedDropActions();

    extern ::Qt::DropActions sipVH_QtWidgets_115(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_115(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQTreeWidget::dropMimeData(::QTreeWidgetItem*a0, int a1, const ::QMimeData*a2, ::Qt::DropAction a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_dropMimeData);

    if (!sipMeth)
        return ::QTreeWidget::dropMimeData(a0, a1, a2, a3);

    extern bool sipVH_QtWidgets_214(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTreeWidgetItem*, int, const ::QMimeData*, ::Qt::DropAction);

    return sipVH_QtWidgets_214(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QMimeData* sipQTreeWidget::mimeData(const QList<::QTreeWidgetItem*> a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeData);

    if (!sipMeth)
        return ::QTreeWidget::mimeData(a0);

    extern ::QMimeData* sipVH_QtWidgets_213(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const QList<::QTreeWidgetItem*>);

    return sipVH_QtWidgets_213(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QStringList sipQTreeWidget::mimeTypes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_mimeTypes);

    if (!sipMeth)
        return ::QTreeWidget::mimeTypes();

    extern ::QStringList sipVH_QtWidgets_123(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_123(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QStyleOptionViewItem sipQTreeWidget::viewOptions() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[4]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewOptions);

    if (!sipMeth)
        return ::QTreeWidget::viewOptions();

    extern ::QStyleOptionViewItem sipVH_QtWidgets_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_70(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::startDrag(::Qt::DropActions a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_startDrag);

    if (!sipMeth)
    {
        ::QTreeWidget::startDrag(a0);
        return;
    }

    extern void sipVH_QtWidgets_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::DropActions);

    sipVH_QtWidgets_69(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QItemSelectionModel::SelectionFlags sipQTreeWidget::selectionCommand(const ::QModelIndex& a0, const ::QEvent*a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[6]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectionCommand);

    if (!sipMeth)
        return ::QTreeWidget::selectionCommand(a0, a1);

    extern ::QItemSelectionModel::SelectionFlags sipVH_QtWidgets_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QEvent*);

    return sipVH_QtWidgets_68(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQTreeWidget::edit(const ::QModelIndex& a0, ::QAbstractItemView::EditTrigger a1, ::QEvent*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_edit);

    if (!sipMeth)
        return ::QTreeWidget::edit(a0, a1, a2);

    extern bool sipVH_QtWidgets_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QAbstractItemView::EditTrigger, ::QEvent*);

    return sipVH_QtWidgets_67(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QModelIndexList sipQTreeWidget::selectedIndexes() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[8]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_selectedIndexes);

    if (!sipMeth)
        return ::QTreeWidget::selectedIndexes();

    extern ::QModelIndexList sipVH_QtWidgets_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_66(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QRegion sipQTreeWidget::visualRegionForSelection(const ::QItemSelection& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[9]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_visualRegionForSelection);

    if (!sipMeth)
        return ::QTreeWidget::visualRegionForSelection(a0);

    extern ::QRegion sipVH_QtWidgets_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QItemSelection&);

    return sipVH_QtWidgets_65(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::setSelection(const ::QRect& a0, ::QItemSelectionModel::SelectionFlags a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_setSelection);

    if (!sipMeth)
    {
        ::QTreeWidget::setSelection(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_64(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QRect&, ::QItemSelectionModel::SelectionFlags);

    sipVH_QtWidgets_64(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQTreeWidget::isIndexHidden(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[11]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_isIndexHidden);

    if (!sipMeth)
        return ::QTreeWidget::isIndexHidden(a0);

    extern bool sipVH_QtWidgets_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_63(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQTreeWidget::verticalOffset() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[12]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_verticalOffset);

    if (!sipMeth)
        return ::QTreeWidget::verticalOffset();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQTreeWidget::horizontalOffset() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[13]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_horizontalOffset);

    if (!sipMeth)
        return ::QTreeWidget::horizontalOffset();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QModelIndex sipQTreeWidget::moveCursor(::QAbstractItemView::CursorAction a0, ::Qt::KeyboardModifiers a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_moveCursor);

    if (!sipMeth)
        return ::QTreeWidget::moveCursor(a0, a1);

    extern ::QModelIndex sipVH_QtWidgets_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QAbstractItemView::CursorAction, ::Qt::KeyboardModifiers);

    return sipVH_QtWidgets_62(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTreeWidget::editorDestroyed(::QObject*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_editorDestroyed);

    if (!sipMeth)
    {
        ::QTreeWidget::editorDestroyed(a0);
        return;
    }

    extern void sipVH_QtWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*);

    sipVH_QtWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::commitData(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_commitData);

    if (!sipMeth)
    {
        ::QTreeWidget::commitData(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::closeEditor(::QWidget*a0, ::QAbstractItemDelegate::EndEditHint a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_closeEditor);

    if (!sipMeth)
    {
        ::QTreeWidget::closeEditor(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*, ::QAbstractItemDelegate::EndEditHint);

    sipVH_QtWidgets_60(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTreeWidget::horizontalScrollbarValueChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_horizontalScrollbarValueChanged);

    if (!sipMeth)
    {
        ::QTreeWidget::horizontalScrollbarValueChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::verticalScrollbarValueChanged(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_verticalScrollbarValueChanged);

    if (!sipMeth)
    {
        ::QTreeWidget::verticalScrollbarValueChanged(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::horizontalScrollbarAction(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[20], &sipPySelf, SIP_NULLPTR, sipName_horizontalScrollbarAction);

    if (!sipMeth)
    {
        ::QTreeWidget::horizontalScrollbarAction(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::verticalScrollbarAction(int a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[21], &sipPySelf, SIP_NULLPTR, sipName_verticalScrollbarAction);

    if (!sipMeth)
    {
        ::QTreeWidget::verticalScrollbarAction(a0);
        return;
    }

    extern void sipVH_QtWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    sipVH_QtWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::updateGeometries()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[22], &sipPySelf, SIP_NULLPTR, sipName_updateGeometries);

    if (!sipMeth)
    {
        ::QTreeWidget::updateGeometries();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::updateEditorGeometries()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[23], &sipPySelf, SIP_NULLPTR, sipName_updateEditorGeometries);

    if (!sipMeth)
    {
        ::QTreeWidget::updateEditorGeometries();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::updateEditorData()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[24], &sipPySelf, SIP_NULLPTR, sipName_updateEditorData);

    if (!sipMeth)
    {
        ::QTreeWidget::updateEditorData();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::currentChanged(const ::QModelIndex& a0, const ::QModelIndex& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[25], &sipPySelf, SIP_NULLPTR, sipName_currentChanged);

    if (!sipMeth)
    {
        ::QTreeWidget::currentChanged(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_58(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QModelIndex&);

    sipVH_QtWidgets_58(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTreeWidget::selectionChanged(const ::QItemSelection& a0, const ::QItemSelection& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[26], &sipPySelf, SIP_NULLPTR, sipName_selectionChanged);

    if (!sipMeth)
    {
        ::QTreeWidget::selectionChanged(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_57(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QItemSelection&, const ::QItemSelection&);

    sipVH_QtWidgets_57(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTreeWidget::rowsAboutToBeRemoved(const ::QModelIndex& a0, int a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[27], &sipPySelf, SIP_NULLPTR, sipName_rowsAboutToBeRemoved);

    if (!sipMeth)
    {
        ::QTreeWidget::rowsAboutToBeRemoved(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int);

    sipVH_QtWidgets_56(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQTreeWidget::rowsInserted(const ::QModelIndex& a0, int a1, int a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[28], &sipPySelf, SIP_NULLPTR, sipName_rowsInserted);

    if (!sipMeth)
    {
        ::QTreeWidget::rowsInserted(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_56(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, int, int);

    sipVH_QtWidgets_56(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQTreeWidget::dataChanged(const ::QModelIndex& a0, const ::QModelIndex& a1, const ::QVector<int>& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[29], &sipPySelf, SIP_NULLPTR, sipName_dataChanged);

    if (!sipMeth)
    {
        ::QTreeWidget::dataChanged(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_55(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, const ::QModelIndex&, const ::QVector<int>&);

    sipVH_QtWidgets_55(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQTreeWidget::selectAll()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[30], &sipPySelf, SIP_NULLPTR, sipName_selectAll);

    if (!sipMeth)
    {
        ::QTreeWidget::selectAll();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::setRootIndex(const ::QModelIndex& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[31], &sipPySelf, SIP_NULLPTR, sipName_setRootIndex);

    if (!sipMeth)
    {
        ::QTreeWidget::setRootIndex(a0);
        return;
    }

    extern void sipVH_QtWidgets_54(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    sipVH_QtWidgets_54(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::reset()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[32], &sipPySelf, SIP_NULLPTR, sipName_reset);

    if (!sipMeth)
    {
        ::QTreeWidget::reset();
        return;
    }

    extern void sipVH_QtWidgets_37(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtWidgets_37(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQTreeWidget::sizeHintForColumn(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[33]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHintForColumn);

    if (!sipMeth)
        return ::QTreeWidget::sizeHintForColumn(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQTreeWidget::sizeHintForRow(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[34]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHintForRow);

    if (!sipMeth)
        return ::QTreeWidget::sizeHintForRow(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QModelIndex sipQTreeWidget::indexAt(const ::QPoint& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[35]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_indexAt);

    if (!sipMeth)
        return ::QTreeWidget::indexAt(a0);

    extern ::QModelIndex sipVH_QtWidgets_53(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QPoint&);

    return sipVH_QtWidgets_53(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::scrollTo(const ::QModelIndex& a0, ::QAbstractItemView::ScrollHint a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[36], &sipPySelf, SIP_NULLPTR, sipName_scrollTo);

    if (!sipMeth)
    {
        ::QTreeWidget::scrollTo(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_52(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&, ::QAbstractItemView::ScrollHint);

    sipVH_QtWidgets_52(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QRect sipQTreeWidget::visualRect(const ::QModelIndex& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[37]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_visualRect);

    if (!sipMeth)
        return ::QTreeWidget::visualRect(a0);

    extern ::QRect sipVH_QtWidgets_51(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QModelIndex&);

    return sipVH_QtWidgets_51(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::keyboardSearch(const ::QString& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[38], &sipPySelf, SIP_NULLPTR, sipName_keyboardSearch);

    if (!sipMeth)
    {
        ::QTreeWidget::keyboardSearch(a0);
        return;
    }

    extern void sipVH_QtWidgets_50(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&);

    sipVH_QtWidgets_50(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::setSelectionModel(::QItemSelectionModel*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[39], &sipPySelf, SIP_NULLPTR, sipName_setSelectionModel);

    if (!sipMeth)
    {
        ::QTreeWidget::setSelectionModel(a0);
        return;
    }

    extern void sipVH_QtWidgets_49(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QItemSelectionModel*);

    sipVH_QtWidgets_49(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[40], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QTreeWidget::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[41], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QTreeWidget::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[42], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[43], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[44], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTreeWidget::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[45], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QTreeWidget::eventFilter(a0, a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQTreeWidget::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[46], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QTreeWidget::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

int sipQTreeWidget::metric(::QPaintDevice::PaintDeviceMetric a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[47]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_metric);

    if (!sipMeth)
        return ::QTreeWidget::metric(a0);

    extern int sipVH_QtWidgets_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintDevice::PaintDeviceMetric);

    return sipVH_QtWidgets_6(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QPaintEngine* sipQTreeWidget::paintEngine() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[48]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_paintEngine);

    if (!sipMeth)
        return ::QTreeWidget::paintEngine();

    extern ::QPaintEngine* sipVH_QtWidgets_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_7(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQTreeWidget::devType() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[49]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_devType);

    if (!sipMeth)
        return ::QTreeWidget::devType();

    extern int sipVH_QtWidgets_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_8(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::setVisible(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[50], &sipPySelf, SIP_NULLPTR, sipName_setVisible);

    if (!sipMeth)
    {
        ::QTreeWidget::setVisible(a0);
        return;
    }

    extern void sipVH_QtWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    sipVH_QtWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQTreeWidget::sizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[51]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sizeHint);

    if (!sipMeth)
        return ::QTreeWidget::sizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QSize sipQTreeWidget::minimumSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[52]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_minimumSizeHint);

    if (!sipMeth)
        return ::QTreeWidget::minimumSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

int sipQTreeWidget::heightForWidth(int a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[53]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_heightForWidth);

    if (!sipMeth)
        return ::QTreeWidget::heightForWidth(a0);

    extern int sipVH_QtWidgets_11(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int);

    return sipVH_QtWidgets_11(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::mousePressEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[54], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::mousePressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::mouseReleaseEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[55], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::mouseReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[56], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::mouseMoveEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[57], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::mouseMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtWidgets_12(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[58], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtWidgets_13(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::keyPressEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[59], &sipPySelf, SIP_NULLPTR, sipName_keyPressEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::keyPressEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::keyReleaseEvent(::QKeyEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[60], &sipPySelf, SIP_NULLPTR, sipName_keyReleaseEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::keyReleaseEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_14(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QKeyEvent*);

    sipVH_QtWidgets_14(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::focusInEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[61], &sipPySelf, SIP_NULLPTR, sipName_focusInEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::focusInEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::focusOutEvent(::QFocusEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[62], &sipPySelf, SIP_NULLPTR, sipName_focusOutEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::focusOutEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QFocusEvent*);

    sipVH_QtWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::enterEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[63], &sipPySelf, SIP_NULLPTR, sipName_enterEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::enterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::leaveEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[64], &sipPySelf, SIP_NULLPTR, sipName_leaveEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::leaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::paintEvent(::QPaintEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[65], &sipPySelf, SIP_NULLPTR, sipName_paintEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::paintEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPaintEvent*);

    sipVH_QtWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::moveEvent(::QMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[66], &sipPySelf, SIP_NULLPTR, sipName_moveEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::moveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMoveEvent*);

    sipVH_QtWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::resizeEvent(::QResizeEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[67], &sipPySelf, SIP_NULLPTR, sipName_resizeEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::resizeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QResizeEvent*);

    sipVH_QtWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::closeEvent(::QCloseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[68], &sipPySelf, SIP_NULLPTR, sipName_closeEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::closeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QCloseEvent*);

    sipVH_QtWidgets_19(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::contextMenuEvent(::QContextMenuEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[69], &sipPySelf, SIP_NULLPTR, sipName_contextMenuEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::contextMenuEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QContextMenuEvent*);

    sipVH_QtWidgets_20(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::tabletEvent(::QTabletEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[70], &sipPySelf, SIP_NULLPTR, sipName_tabletEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::tabletEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_21(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTabletEvent*);

    sipVH_QtWidgets_21(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::actionEvent(::QActionEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[71], &sipPySelf, SIP_NULLPTR, sipName_actionEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::actionEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QActionEvent*);

    sipVH_QtWidgets_22(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::dragEnterEvent(::QDragEnterEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[72], &sipPySelf, SIP_NULLPTR, sipName_dragEnterEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::dragEnterEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragEnterEvent*);

    sipVH_QtWidgets_23(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::dragMoveEvent(::QDragMoveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[73], &sipPySelf, SIP_NULLPTR, sipName_dragMoveEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::dragMoveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragMoveEvent*);

    sipVH_QtWidgets_24(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::dragLeaveEvent(::QDragLeaveEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[74], &sipPySelf, SIP_NULLPTR, sipName_dragLeaveEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::dragLeaveEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDragLeaveEvent*);

    sipVH_QtWidgets_25(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::dropEvent(::QDropEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[75], &sipPySelf, SIP_NULLPTR, sipName_dropEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::dropEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QDropEvent*);

    sipVH_QtWidgets_26(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::showEvent(::QShowEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[76], &sipPySelf, SIP_NULLPTR, sipName_showEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::showEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QShowEvent*);

    sipVH_QtWidgets_27(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::hideEvent(::QHideEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[77], &sipPySelf, SIP_NULLPTR, sipName_hideEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::hideEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QHideEvent*);

    sipVH_QtWidgets_28(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::changeEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[78], &sipPySelf, SIP_NULLPTR, sipName_changeEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::changeEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::inputMethodEvent(::QInputMethodEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[79], &sipPySelf, SIP_NULLPTR, sipName_inputMethodEvent);

    if (!sipMeth)
    {
        ::QTreeWidget::inputMethodEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_29(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QInputMethodEvent*);

    sipVH_QtWidgets_29(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QVariant sipQTreeWidget::inputMethodQuery(::Qt::InputMethodQuery a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[80]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_inputMethodQuery);

    if (!sipMeth)
        return ::QTreeWidget::inputMethodQuery(a0);

    extern ::QVariant sipVH_QtWidgets_30(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::Qt::InputMethodQuery);

    return sipVH_QtWidgets_30(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTreeWidget::focusNextPrevChild(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[81], &sipPySelf, SIP_NULLPTR, sipName_focusNextPrevChild);

    if (!sipMeth)
        return ::QTreeWidget::focusNextPrevChild(a0);

    extern bool sipVH_QtWidgets_31(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_QtWidgets_31(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQTreeWidget::hasHeightForWidth() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[82]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_hasHeightForWidth);

    if (!sipMeth)
        return ::QTreeWidget::hasHeightForWidth();

    extern bool sipVH_QtWidgets_32(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_32(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQTreeWidget::nativeEvent(const ::QByteArray& a0, void*a1, long*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[83], &sipPySelf, SIP_NULLPTR, sipName_nativeEvent);

    if (!sipMeth)
        return ::QTreeWidget::nativeEvent(a0, a1, a2);

    extern bool sipVH_QtWidgets_33(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QByteArray&, void*, long*);

    return sipVH_QtWidgets_33(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QPainter* sipQTreeWidget::sharedPainter() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[84]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_sharedPainter);

    if (!sipMeth)
        return ::QTreeWidget::sharedPainter();

    extern ::QPainter* sipVH_QtWidgets_34(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_34(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQTreeWidget::initPainter(::QPainter*a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[85]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_initPainter);

    if (!sipMeth)
    {
        ::QTreeWidget::initPainter(a0);
        return;
    }

    extern void sipVH_QtWidgets_35(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*);

    sipVH_QtWidgets_35(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QSize sipQTreeWidget::viewportSizeHint() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[86]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_viewportSizeHint);

    if (!sipMeth)
        return ::QTreeWidget::viewportSizeHint();

    extern ::QSize sipVH_QtWidgets_10(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_10(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQTreeWidget::viewportEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[87], &sipPySelf, SIP_NULLPTR, sipName_viewportEvent);

    if (!sipMeth)
        return ::QTreeWidget::viewportEvent(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::scrollContentsBy(int a0, int a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[88], &sipPySelf, SIP_NULLPTR, sipName_scrollContentsBy);

    if (!sipMeth)
    {
        ::QTreeWidget::scrollContentsBy(a0, a1);
        return;
    }

    extern void sipVH_QtWidgets_46(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, int, int);

    sipVH_QtWidgets_46(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQTreeWidget::setupViewport(::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[89], &sipPySelf, SIP_NULLPTR, sipName_setupViewport);

    if (!sipMeth)
    {
        ::QTreeWidget::setupViewport(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWidget*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQTreeWidget::drawRow(::QPainter*a0, const ::QStyleOptionViewItem& a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[90]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawRow);

    if (!sipMeth)
    {
        ::QTreeWidget::drawRow(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_38(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QStyleOptionViewItem&, const ::QModelIndex&);

    sipVH_QtWidgets_38(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQTreeWidget::drawBranches(::QPainter*a0, const ::QRect& a1, const ::QModelIndex& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[91]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_drawBranches);

    if (!sipMeth)
    {
        ::QTreeWidget::drawBranches(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWidgets_208(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QPainter*, const ::QRect&, const ::QModelIndex&);

    sipVH_QtWidgets_208(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}


PyDoc_STRVAR(doc_QTreeWidget_columnCount, "columnCount(self) -> int");

extern "C" {static PyObject *meth_QTreeWidget_columnCount(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_columnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->columnCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_columnCount, doc_QTreeWidget_columnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setColumnCount, "setColumnCount(self, columns: int)");

extern "C" {static PyObject *meth_QTreeWidget_setColumnCount(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setColumnCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0))
        {
            sipCpp->setColumnCount(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setColumnCount, doc_QTreeWidget_setColumnCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_topLevelItem, "topLevelItem(self, index: int) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_topLevelItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_topLevelItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->topLevelItem(a0);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_topLevelItem, doc_QTreeWidget_topLevelItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_topLevelItemCount, "topLevelItemCount(self) -> int");

extern "C" {static PyObject *meth_QTreeWidget_topLevelItemCount(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_topLevelItemCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->topLevelItemCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_topLevelItemCount, doc_QTreeWidget_topLevelItemCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_insertTopLevelItem, "insertTopLevelItem(self, index: int, item: Optional[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_insertTopLevelItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_insertTopLevelItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QTreeWidgetItem* a1;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ:", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0, sipType_QTreeWidgetItem, &a1))
        {
            sipCpp->insertTopLevelItem(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_insertTopLevelItem, doc_QTreeWidget_insertTopLevelItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_addTopLevelItem, "addTopLevelItem(self, item: Optional[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_addTopLevelItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_addTopLevelItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            sipCpp->addTopLevelItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_addTopLevelItem, doc_QTreeWidget_addTopLevelItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_takeTopLevelItem, "takeTopLevelItem(self, index: int) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_takeTopLevelItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_takeTopLevelItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->takeTopLevelItem(a0);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_takeTopLevelItem, doc_QTreeWidget_takeTopLevelItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_indexOfTopLevelItem, "indexOfTopLevelItem(self, item: Optional[QTreeWidgetItem]) -> int");

extern "C" {static PyObject *meth_QTreeWidget_indexOfTopLevelItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_indexOfTopLevelItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            int sipRes;

            sipRes = sipCpp->indexOfTopLevelItem(a0);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_indexOfTopLevelItem, doc_QTreeWidget_indexOfTopLevelItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_insertTopLevelItems, "insertTopLevelItems(self, index: int, items: Iterable[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_insertTopLevelItems(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_insertTopLevelItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const QList<::QTreeWidgetItem*>* a1;
        int a1State = 0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ3", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0, sipType_QList_0101QTreeWidgetItem, &a1, &a1State))
        {
            sipCpp->insertTopLevelItems(a0, *a1);
            sipReleaseType(const_cast<QList<::QTreeWidgetItem*> *>(a1), sipType_QList_0101QTreeWidgetItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_insertTopLevelItems, doc_QTreeWidget_insertTopLevelItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_addTopLevelItems, "addTopLevelItems(self, items: Iterable[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_addTopLevelItems(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_addTopLevelItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList<::QTreeWidgetItem*>* a0;
        int a0State = 0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ3", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QList_0101QTreeWidgetItem, &a0, &a0State))
        {
            sipCpp->addTopLevelItems(*a0);
            sipReleaseType(const_cast<QList<::QTreeWidgetItem*> *>(a0), sipType_QList_0101QTreeWidgetItem, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_addTopLevelItems, doc_QTreeWidget_addTopLevelItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_headerItem, "headerItem(self) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_headerItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_headerItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->headerItem();

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_headerItem, doc_QTreeWidget_headerItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setHeaderItem, "setHeaderItem(self, item: Optional[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_setHeaderItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setHeaderItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            sipCpp->setHeaderItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setHeaderItem, doc_QTreeWidget_setHeaderItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setHeaderLabels, "setHeaderLabels(self, labels: Iterable[Optional[str]])");

extern "C" {static PyObject *meth_QTreeWidget_setHeaderLabels(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setHeaderLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setHeaderLabels(*a0);
            sipReleaseType(const_cast<::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setHeaderLabels, doc_QTreeWidget_setHeaderLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_currentItem, "currentItem(self) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_currentItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_currentItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->currentItem();

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_currentItem, doc_QTreeWidget_currentItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_currentColumn, "currentColumn(self) -> int");

extern "C" {static PyObject *meth_QTreeWidget_currentColumn(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_currentColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->currentColumn();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_currentColumn, doc_QTreeWidget_currentColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setCurrentItem, "setCurrentItem(self, item: Optional[QTreeWidgetItem])\n"
"setCurrentItem(self, item: Optional[QTreeWidgetItem], column: int)\n"
"setCurrentItem(self, item: Optional[QTreeWidgetItem], column: int, command: Union[QItemSelectionModel.SelectionFlags, QItemSelectionModel.SelectionFlag])");

extern "C" {static PyObject *meth_QTreeWidget_setCurrentItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setCurrentItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            sipCpp->setCurrentItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QTreeWidgetItem* a0;
        int a1;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            sipCpp->setCurrentItem(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QTreeWidgetItem* a0;
        int a1;
        ::QItemSelectionModel::SelectionFlags* a2;
        int a2State = 0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8iJ1", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1, sipType_QItemSelectionModel_SelectionFlags, &a2, &a2State))
        {
            sipCpp->setCurrentItem(a0, a1, *a2);
            sipReleaseType(a2, sipType_QItemSelectionModel_SelectionFlags, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setCurrentItem, doc_QTreeWidget_setCurrentItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_itemAt, "itemAt(self, p: QPoint) -> Optional[QTreeWidgetItem]\n"
"itemAt(self, ax: int, ay: int) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_itemAt(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_itemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QPoint, &a0))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->itemAt(*a0);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    {
        int a0;
        int a1;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0, &a1))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->itemAt(a0, a1);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_itemAt, doc_QTreeWidget_itemAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_visualItemRect, "visualItemRect(self, item: Optional[QTreeWidgetItem]) -> QRect");

extern "C" {static PyObject *meth_QTreeWidget_visualItemRect(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_visualItemRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->visualItemRect(a0));

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_visualItemRect, doc_QTreeWidget_visualItemRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_sortColumn, "sortColumn(self) -> int");

extern "C" {static PyObject *meth_QTreeWidget_sortColumn(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_sortColumn(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sortColumn();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_sortColumn, doc_QTreeWidget_sortColumn);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_sortItems, "sortItems(self, column: int, order: Qt.SortOrder)");

extern "C" {static PyObject *meth_QTreeWidget_sortItems(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_sortItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::Qt::SortOrder a1;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiE", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0, sipType_Qt_SortOrder, &a1))
        {
            sipCpp->sortItems(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_sortItems, doc_QTreeWidget_sortItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_editItem, "editItem(self, item: Optional[QTreeWidgetItem], column: int = 0)");

extern "C" {static PyObject *meth_QTreeWidget_editItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_editItem(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1 = 0;
        ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            sipCpp->editItem(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_editItem, doc_QTreeWidget_editItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_openPersistentEditor, "openPersistentEditor(self, item: Optional[QTreeWidgetItem], column: int = 0)");

extern "C" {static PyObject *meth_QTreeWidget_openPersistentEditor(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_openPersistentEditor(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1 = 0;
        ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            sipCpp->openPersistentEditor(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_openPersistentEditor, doc_QTreeWidget_openPersistentEditor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_closePersistentEditor, "closePersistentEditor(self, item: Optional[QTreeWidgetItem], column: int = 0)");

extern "C" {static PyObject *meth_QTreeWidget_closePersistentEditor(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_closePersistentEditor(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1 = 0;
        ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            sipCpp->closePersistentEditor(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_closePersistentEditor, doc_QTreeWidget_closePersistentEditor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_itemWidget, "itemWidget(self, item: Optional[QTreeWidgetItem], column: int) -> Optional[QWidget]");

extern "C" {static PyObject *meth_QTreeWidget_itemWidget(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_itemWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->itemWidget(a0, a1);

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_itemWidget, doc_QTreeWidget_itemWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setItemWidget, "setItemWidget(self, item: Optional[QTreeWidgetItem], column: int, widget: Optional[QWidget])");

extern "C" {static PyObject *meth_QTreeWidget_setItemWidget(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setItemWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1;
        ::QWidget* a2;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8iJ:", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1, sipType_QWidget, &a2))
        {
#line 160 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qtreewidget.sip"
        // We have to break the association with any existing widget.  Note that I'm
        // not sure this is really necessary as it should get tidied up when Qt
        // destroys any current widget, except (possibly) when the widget wasn't
        // created from PyQt.  See also removeItemWidget(), QListWidget and
        // QTableWidget.
        QWidget *w = sipCpp->itemWidget(a0, a1);
        
        if (w)
        {
            PyObject *wo = sipGetPyObject(w, sipType_QWidget);
        
            if (wo)
                sipTransferTo(wo, 0);
        }
        
        Py_BEGIN_ALLOW_THREADS
        sipCpp->setItemWidget(a0, a1, a2);
        Py_END_ALLOW_THREADS
#line 2776 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setItemWidget, doc_QTreeWidget_setItemWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_selectedItems, "selectedItems(self) -> List[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_selectedItems(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_selectedItems(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            QList<::QTreeWidgetItem*>*sipRes;

            sipRes = new QList<::QTreeWidgetItem*>(sipCpp->selectedItems());

            return sipConvertFromNewType(sipRes, sipType_QList_0101QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_selectedItems, doc_QTreeWidget_selectedItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_findItems, "findItems(self, text: Optional[str], flags: Union[Qt.MatchFlags, Qt.MatchFlag], column: int = 0) -> List[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_findItems(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_findItems(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::Qt::MatchFlags* a1;
        int a1State = 0;
        int a2 = 0;
        const ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1|i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QString, &a0, &a0State, sipType_Qt_MatchFlags, &a1, &a1State, &a2))
        {
            QList<::QTreeWidgetItem*>*sipRes;

            sipRes = new QList<::QTreeWidgetItem*>(sipCpp->findItems(*a0, *a1, a2));
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_Qt_MatchFlags, a1State);

            return sipConvertFromNewType(sipRes, sipType_QList_0101QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_findItems, doc_QTreeWidget_findItems);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_scrollToItem, "scrollToItem(self, item: Optional[QTreeWidgetItem], hint: QAbstractItemView.ScrollHint = QAbstractItemView.EnsureVisible)");

extern "C" {static PyObject *meth_QTreeWidget_scrollToItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_scrollToItem(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        ::QAbstractItemView::ScrollHint a1 = QAbstractItemView::EnsureVisible;
        ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_hint,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|E", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, sipType_QAbstractItemView_ScrollHint, &a1))
        {
            sipCpp->scrollToItem(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_scrollToItem, doc_QTreeWidget_scrollToItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_expandItem, "expandItem(self, item: Optional[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_expandItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_expandItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            sipCpp->expandItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_expandItem, doc_QTreeWidget_expandItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_collapseItem, "collapseItem(self, item: Optional[QTreeWidgetItem])");

extern "C" {static PyObject *meth_QTreeWidget_collapseItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_collapseItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            sipCpp->collapseItem(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_collapseItem, doc_QTreeWidget_collapseItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_clear, "clear(self)");

extern "C" {static PyObject *meth_QTreeWidget_clear(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_clear(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            sipCpp->clear();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_clear, doc_QTreeWidget_clear);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_mimeTypes, "mimeTypes(self) -> List[str]");

extern "C" {static PyObject *meth_QTreeWidget_mimeTypes(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_mimeTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList((sipSelfWasArg ? sipCpp->::QTreeWidget::mimeTypes() : sipCpp->mimeTypes()));

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_mimeTypes, doc_QTreeWidget_mimeTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_mimeData, "mimeData(self, items: Iterable[QTreeWidgetItem]) -> Optional[QMimeData]");

extern "C" {static PyObject *meth_QTreeWidget_mimeData(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_mimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const QList<::QTreeWidgetItem*>* a0;
        int a0State = 0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QList_0101QTreeWidgetItem, &a0, &a0State))
        {
            ::QMimeData*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QTreeWidget::mimeData(*a0) : sipCpp->mimeData(*a0));
            sipReleaseType(const_cast<QList<::QTreeWidgetItem*> *>(a0), sipType_QList_0101QTreeWidgetItem, a0State);

            return sipConvertFromType(sipRes, sipType_QMimeData, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_mimeData, doc_QTreeWidget_mimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_dropMimeData, "dropMimeData(self, parent: Optional[QTreeWidgetItem], index: int, data: Optional[QMimeData], action: Qt.DropAction) -> bool");

extern "C" {static PyObject *meth_QTreeWidget_dropMimeData(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_dropMimeData(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTreeWidgetItem* a0;
        int a1;
        const ::QMimeData* a2;
        ::Qt::DropAction a3;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8iJ8E", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1, sipType_QMimeData, &a2, sipType_Qt_DropAction, &a3))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QTreeWidget::dropMimeData(a0, a1, a2, a3) : sipCpp->dropMimeData(a0, a1, a2, a3));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_dropMimeData, doc_QTreeWidget_dropMimeData);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_supportedDropActions, "supportedDropActions(self) -> Qt.DropActions");

extern "C" {static PyObject *meth_QTreeWidget_supportedDropActions(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_supportedDropActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            ::Qt::DropActions*sipRes;

            sipRes = new ::Qt::DropActions((sipSelfWasArg ? sipCpp->::QTreeWidget::supportedDropActions() : sipCpp->supportedDropActions()));

            return sipConvertFromNewType(sipRes, sipType_Qt_DropActions, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_supportedDropActions, doc_QTreeWidget_supportedDropActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_indexFromItem, "indexFromItem(self, item: Optional[QTreeWidgetItem], column: int = 0) -> QModelIndex");

extern "C" {static PyObject *meth_QTreeWidget_indexFromItem(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_indexFromItem(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1 = 0;
        const ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "pJ8|i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            ::QModelIndex*sipRes;

            sipRes = new ::QModelIndex(sipCpp->indexFromItem(a0, a1));

            return sipConvertFromNewType(sipRes, sipType_QModelIndex, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_indexFromItem, doc_QTreeWidget_indexFromItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_itemFromIndex, "itemFromIndex(self, index: QModelIndex) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_itemFromIndex(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_itemFromIndex(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QModelIndex* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QModelIndex, &a0))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->itemFromIndex(*a0);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_itemFromIndex, doc_QTreeWidget_itemFromIndex);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_event, "event(self, e: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QTreeWidget_event(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QTreeWidget::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_event, doc_QTreeWidget_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_dropEvent, "dropEvent(self, event: Optional[QDropEvent])");

extern "C" {static PyObject *meth_QTreeWidget_dropEvent(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_dropEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QDropEvent* a0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QDropEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QTreeWidget::dropEvent(a0) : sipCpp->dropEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_dropEvent, doc_QTreeWidget_dropEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_invisibleRootItem, "invisibleRootItem(self) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_invisibleRootItem(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_invisibleRootItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QTreeWidget, &sipCpp))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->invisibleRootItem();

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, sipSelf);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_invisibleRootItem, doc_QTreeWidget_invisibleRootItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setHeaderLabel, "setHeaderLabel(self, alabel: Optional[str])");

extern "C" {static PyObject *meth_QTreeWidget_setHeaderLabel(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setHeaderLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setHeaderLabel(*a0);
            sipReleaseType(const_cast<::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setHeaderLabel, doc_QTreeWidget_setHeaderLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_isFirstItemColumnSpanned, "isFirstItemColumnSpanned(self, item: Optional[QTreeWidgetItem]) -> bool");

extern "C" {static PyObject *meth_QTreeWidget_isFirstItemColumnSpanned(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_isFirstItemColumnSpanned(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isFirstItemColumnSpanned(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_isFirstItemColumnSpanned, doc_QTreeWidget_isFirstItemColumnSpanned);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setFirstItemColumnSpanned, "setFirstItemColumnSpanned(self, item: Optional[QTreeWidgetItem], span: bool)");

extern "C" {static PyObject *meth_QTreeWidget_setFirstItemColumnSpanned(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setFirstItemColumnSpanned(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        bool a1;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8b", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            sipCpp->setFirstItemColumnSpanned(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setFirstItemColumnSpanned, doc_QTreeWidget_setFirstItemColumnSpanned);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_itemAbove, "itemAbove(self, item: Optional[QTreeWidgetItem]) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_itemAbove(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_itemAbove(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->itemAbove(a0);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_itemAbove, doc_QTreeWidget_itemAbove);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_itemBelow, "itemBelow(self, item: Optional[QTreeWidgetItem]) -> Optional[QTreeWidgetItem]");

extern "C" {static PyObject *meth_QTreeWidget_itemBelow(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_itemBelow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QTreeWidgetItem* a0;
        const ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0))
        {
            ::QTreeWidgetItem*sipRes;

            sipRes = sipCpp->itemBelow(a0);

            return sipConvertFromType(sipRes, sipType_QTreeWidgetItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_itemBelow, doc_QTreeWidget_itemBelow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_removeItemWidget, "removeItemWidget(self, item: Optional[QTreeWidgetItem], column: int)");

extern "C" {static PyObject *meth_QTreeWidget_removeItemWidget(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_removeItemWidget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
#line 220 "/usr/src/debug/python3-pyqt5/5.15.10/sip/QtWidgets/qtreewidget.sip"
        // We have to break the association with any existing widget.
        QWidget *w = sipCpp->itemWidget(a0, a1);
        
        if (w)
        {
            PyObject *wo = sipGetPyObject(w, sipType_QWidget);
        
            if (wo)
                sipTransferTo(wo, 0);
        }
        
        Py_BEGIN_ALLOW_THREADS
        sipCpp->removeItemWidget(a0, a1);
        Py_END_ALLOW_THREADS
#line 3384 "/usr/src/debug/python3-pyqt5/5.15.10/QtWidgets/sipQtWidgetsQTreeWidget.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_removeItemWidget, doc_QTreeWidget_removeItemWidget);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_setSelectionModel, "setSelectionModel(self, selectionModel: Optional[QItemSelectionModel])");

extern "C" {static PyObject *meth_QTreeWidget_setSelectionModel(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setSelectionModel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QItemSelectionModel* a0;
        PyObject *a0Keep;
        ::QTreeWidget *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QTreeWidget, &sipCpp, &a0Keep, sipType_QItemSelectionModel, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QTreeWidget::setSelectionModel(a0) : sipCpp->setSelectionModel(a0));

            sipKeepReference(sipSelf, -53, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_setSelectionModel, doc_QTreeWidget_setSelectionModel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QTreeWidget_isPersistentEditorOpen, "isPersistentEditorOpen(self, item: Optional[QTreeWidgetItem], column: int = 0) -> bool");

extern "C" {static PyObject *meth_QTreeWidget_isPersistentEditorOpen(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_isPersistentEditorOpen(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QTreeWidgetItem* a0;
        int a1 = 0;
        const ::QTreeWidget *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_column,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8|i", &sipSelf, sipType_QTreeWidget, &sipCpp, sipType_QTreeWidgetItem, &a0, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->isPersistentEditorOpen(a0, a1);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QTreeWidget, sipName_isPersistentEditorOpen, doc_QTreeWidget_isPersistentEditorOpen);

    return SIP_NULLPTR;
}


extern "C" {static PyObject *meth_QTreeWidget_setModel(PyObject *, PyObject *);}
static PyObject *meth_QTreeWidget_setModel(PyObject *, PyObject *)
{

    sipNoMethod(SIP_NULLPTR, sipName_QTreeWidget, sipName_setModel, SIP_NULLPTR);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QTreeWidget(void *, const sipTypeDef *);}
static void *cast_QTreeWidget(void *sipCppV, const sipTypeDef *targetType)
{
    ::QTreeWidget *sipCpp = reinterpret_cast<::QTreeWidget *>(sipCppV);

    if (targetType == sipType_QTreeWidget)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QTreeView)->ctd_cast(static_cast<::QTreeView *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QTreeWidget(void *, int);}
static void release_QTreeWidget(void *sipCppV, int)
{
    ::QTreeWidget *sipCpp = reinterpret_cast<::QTreeWidget *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QTreeWidget(Py_ssize_t);}
static void *array_QTreeWidget(Py_ssize_t sipNrElem)
{
    return new ::QTreeWidget[sipNrElem];
}


extern "C" {static void array_delete_QTreeWidget(void *);}
static void array_delete_QTreeWidget(void *sipCpp)
{
    delete[] reinterpret_cast<::QTreeWidget *>(sipCpp);
}


extern "C" {static void dealloc_QTreeWidget(sipSimpleWrapper *);}
static void dealloc_QTreeWidget(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQTreeWidget *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QTreeWidget(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QTreeWidget(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QTreeWidget(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQTreeWidget *sipCpp = SIP_NULLPTR;

    {
        ::QWidget* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QWidget, &a0, sipOwner))
        {
            sipCpp = new sipQTreeWidget(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QTreeWidget[] = {{449, 255, 1}};


static PyMethodDef methods_QTreeWidget[] = {
    {sipName_addTopLevelItem, meth_QTreeWidget_addTopLevelItem, METH_VARARGS, doc_QTreeWidget_addTopLevelItem},
    {sipName_addTopLevelItems, meth_QTreeWidget_addTopLevelItems, METH_VARARGS, doc_QTreeWidget_addTopLevelItems},
    {sipName_clear, meth_QTreeWidget_clear, METH_VARARGS, doc_QTreeWidget_clear},
    {sipName_closePersistentEditor, SIP_MLMETH_CAST(meth_QTreeWidget_closePersistentEditor), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_closePersistentEditor},
    {sipName_collapseItem, meth_QTreeWidget_collapseItem, METH_VARARGS, doc_QTreeWidget_collapseItem},
    {sipName_columnCount, meth_QTreeWidget_columnCount, METH_VARARGS, doc_QTreeWidget_columnCount},
    {sipName_currentColumn, meth_QTreeWidget_currentColumn, METH_VARARGS, doc_QTreeWidget_currentColumn},
    {sipName_currentItem, meth_QTreeWidget_currentItem, METH_VARARGS, doc_QTreeWidget_currentItem},
    {sipName_dropEvent, meth_QTreeWidget_dropEvent, METH_VARARGS, doc_QTreeWidget_dropEvent},
    {sipName_dropMimeData, meth_QTreeWidget_dropMimeData, METH_VARARGS, doc_QTreeWidget_dropMimeData},
    {sipName_editItem, SIP_MLMETH_CAST(meth_QTreeWidget_editItem), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_editItem},
    {sipName_event, meth_QTreeWidget_event, METH_VARARGS, doc_QTreeWidget_event},
    {sipName_expandItem, meth_QTreeWidget_expandItem, METH_VARARGS, doc_QTreeWidget_expandItem},
    {sipName_findItems, SIP_MLMETH_CAST(meth_QTreeWidget_findItems), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_findItems},
    {sipName_headerItem, meth_QTreeWidget_headerItem, METH_VARARGS, doc_QTreeWidget_headerItem},
    {sipName_indexFromItem, SIP_MLMETH_CAST(meth_QTreeWidget_indexFromItem), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_indexFromItem},
    {sipName_indexOfTopLevelItem, meth_QTreeWidget_indexOfTopLevelItem, METH_VARARGS, doc_QTreeWidget_indexOfTopLevelItem},
    {sipName_insertTopLevelItem, meth_QTreeWidget_insertTopLevelItem, METH_VARARGS, doc_QTreeWidget_insertTopLevelItem},
    {sipName_insertTopLevelItems, meth_QTreeWidget_insertTopLevelItems, METH_VARARGS, doc_QTreeWidget_insertTopLevelItems},
    {sipName_invisibleRootItem, meth_QTreeWidget_invisibleRootItem, METH_VARARGS, doc_QTreeWidget_invisibleRootItem},
    {sipName_isFirstItemColumnSpanned, meth_QTreeWidget_isFirstItemColumnSpanned, METH_VARARGS, doc_QTreeWidget_isFirstItemColumnSpanned},
    {sipName_isPersistentEditorOpen, SIP_MLMETH_CAST(meth_QTreeWidget_isPersistentEditorOpen), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_isPersistentEditorOpen},
    {sipName_itemAbove, meth_QTreeWidget_itemAbove, METH_VARARGS, doc_QTreeWidget_itemAbove},
    {sipName_itemAt, meth_QTreeWidget_itemAt, METH_VARARGS, doc_QTreeWidget_itemAt},
    {sipName_itemBelow, meth_QTreeWidget_itemBelow, METH_VARARGS, doc_QTreeWidget_itemBelow},
    {sipName_itemFromIndex, meth_QTreeWidget_itemFromIndex, METH_VARARGS, doc_QTreeWidget_itemFromIndex},
    {sipName_itemWidget, meth_QTreeWidget_itemWidget, METH_VARARGS, doc_QTreeWidget_itemWidget},
    {sipName_mimeData, meth_QTreeWidget_mimeData, METH_VARARGS, doc_QTreeWidget_mimeData},
    {sipName_mimeTypes, meth_QTreeWidget_mimeTypes, METH_VARARGS, doc_QTreeWidget_mimeTypes},
    {sipName_openPersistentEditor, SIP_MLMETH_CAST(meth_QTreeWidget_openPersistentEditor), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_openPersistentEditor},
    {sipName_removeItemWidget, meth_QTreeWidget_removeItemWidget, METH_VARARGS, doc_QTreeWidget_removeItemWidget},
    {sipName_scrollToItem, SIP_MLMETH_CAST(meth_QTreeWidget_scrollToItem), METH_VARARGS|METH_KEYWORDS, doc_QTreeWidget_scrollToItem},
    {sipName_selectedItems, meth_QTreeWidget_selectedItems, METH_VARARGS, doc_QTreeWidget_selectedItems},
    {sipName_setColumnCount, meth_QTreeWidget_setColumnCount, METH_VARARGS, doc_QTreeWidget_setColumnCount},
    {sipName_setCurrentItem, meth_QTreeWidget_setCurrentItem, METH_VARARGS, doc_QTreeWidget_setCurrentItem},
    {sipName_setFirstItemColumnSpanned, meth_QTreeWidget_setFirstItemColumnSpanned, METH_VARARGS, doc_QTreeWidget_setFirstItemColumnSpanned},
    {sipName_setHeaderItem, meth_QTreeWidget_setHeaderItem, METH_VARARGS, doc_QTreeWidget_setHeaderItem},
    {sipName_setHeaderLabel, meth_QTreeWidget_setHeaderLabel, METH_VARARGS, doc_QTreeWidget_setHeaderLabel},
    {sipName_setHeaderLabels, meth_QTreeWidget_setHeaderLabels, METH_VARARGS, doc_QTreeWidget_setHeaderLabels},
    {sipName_setItemWidget, meth_QTreeWidget_setItemWidget, METH_VARARGS, doc_QTreeWidget_setItemWidget},
    {sipName_setModel, meth_QTreeWidget_setModel, METH_VARARGS, SIP_NULLPTR},
    {sipName_setSelectionModel, meth_QTreeWidget_setSelectionModel, METH_VARARGS, doc_QTreeWidget_setSelectionModel},
    {sipName_sortColumn, meth_QTreeWidget_sortColumn, METH_VARARGS, doc_QTreeWidget_sortColumn},
    {sipName_sortItems, meth_QTreeWidget_sortItems, METH_VARARGS, doc_QTreeWidget_sortItems},
    {sipName_supportedDropActions, meth_QTreeWidget_supportedDropActions, METH_VARARGS, doc_QTreeWidget_supportedDropActions},
    {sipName_takeTopLevelItem, meth_QTreeWidget_takeTopLevelItem, METH_VARARGS, doc_QTreeWidget_takeTopLevelItem},
    {sipName_topLevelItem, meth_QTreeWidget_topLevelItem, METH_VARARGS, doc_QTreeWidget_topLevelItem},
    {sipName_topLevelItemCount, meth_QTreeWidget_topLevelItemCount, METH_VARARGS, doc_QTreeWidget_topLevelItemCount},
    {sipName_visualItemRect, meth_QTreeWidget_visualItemRect, METH_VARARGS, doc_QTreeWidget_visualItemRect}
};

PyDoc_STRVAR(doc_QTreeWidget, "\1QTreeWidget(parent: Optional[QWidget] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QTreeWidget[] = {
    {"itemSelectionChanged()", "\1itemSelectionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)", "\1currentItemChanged(self, current: Optional[QTreeWidgetItem], previous: Optional[QTreeWidgetItem])", SIP_NULLPTR, SIP_NULLPTR},
    {"itemCollapsed(QTreeWidgetItem*)", "\1itemCollapsed(self, item: Optional[QTreeWidgetItem])", SIP_NULLPTR, SIP_NULLPTR},
    {"itemExpanded(QTreeWidgetItem*)", "\1itemExpanded(self, item: Optional[QTreeWidgetItem])", SIP_NULLPTR, SIP_NULLPTR},
    {"itemChanged(QTreeWidgetItem*,int)", "\1itemChanged(self, item: Optional[QTreeWidgetItem], column: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemEntered(QTreeWidgetItem*,int)", "\1itemEntered(self, item: Optional[QTreeWidgetItem], column: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemActivated(QTreeWidgetItem*,int)", "\1itemActivated(self, item: Optional[QTreeWidgetItem], column: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemDoubleClicked(QTreeWidgetItem*,int)", "\1itemDoubleClicked(self, item: Optional[QTreeWidgetItem], column: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemClicked(QTreeWidgetItem*,int)", "\1itemClicked(self, item: Optional[QTreeWidgetItem], column: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemPressed(QTreeWidgetItem*,int)", "\1itemPressed(self, item: Optional[QTreeWidgetItem], column: int)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QTreeWidget = {
    &::QTreeWidget::staticMetaObject,
    0,
    signals_QTreeWidget,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QTreeWidget = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QTreeWidget,
        SIP_NULLPTR,
        &plugin_QTreeWidget,
    },
    {
        sipNameNr_QTreeWidget,
        {0, 0, 1},
        49, methods_QTreeWidget,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QTreeWidget,
    -1,
    -1,
    supers_QTreeWidget,
    SIP_NULLPTR,
    init_type_QTreeWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QTreeWidget,
    SIP_NULLPTR,
    array_QTreeWidget,
    SIP_NULLPTR,
    release_QTreeWidget,
    cast_QTreeWidget,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QTreeWidget,
    sizeof (::QTreeWidget),
};
